rm(list=ls())
getwd()
setwd("pathway") # Adapt this to your own pathway!

## read the data from file and attach it
count_data <- read.table("sinclair.txt", header=T)
attach(count_data)

Tab_odds_fem  <- Tab_odds_mal <- array(0,c(3,4))
Tab_odds_fem_f  <- Tab_odds_mal_f  <- array(0,c(3,4))
colnames(Tab_odds_fem) <- c("Females","median", "2.5%", "97.5%")
rownames(Tab_odds_fem) <- c("TG_OG","TG_SWF","SWF_OG")
colnames(Tab_odds_mal) <- c("Males","median", "2.5%", "97.5%")
rownames(Tab_odds_mal) <- c("TG_OG","TG_SWF","SWF_OG")

###Bayesian approach 
library(R2OpenBUGS)

for (k in 1:2){
for (j in 1:3) {
if (k==1) {
#females
if (j ==1) { tabla_datos <- c(8, 16 ,32, 26)}
if (j ==2) { tabla_datos <- c(8, 16, 26, 6)}
if (j ==3) { tabla_datos <- c(26, 6, 32,26)}
          }
if (k==2) {
#males
if (j ==1) { tabla_datos <- c(10, 26 ,43, 12)}
if (j ==2) { tabla_datos <- c(10, 26, 14, 7)}
if (j ==3) { tabla_datos <- c(14,7, 43, 12)}
          }
       
### Fitting the model
# Write model
Logmodel<-function(){
  for (i in 1:4)  # for each of the 6 cells in the table
  {
    # calculate relative frequency of species
    log(p[i]) <- k1[PRED[i]] + k2[NPRED[i]] + k12[PRED[i], NPRED[i]]
  }
  pp <- sum(p[1:4])  # sum of the 6 values of p[]
  for (i in 1:4)  # for each of the 6 cells in the table
  {
    pr[i] <- p[i] / pp  # re-scale so pr[] are probabilities
  }
  odds_1 <- pr[4] / pr[2]  # odds for 
  odds_2 <- pr[3] / pr[1]  # odds for 
  odds_ratio_12 <- odds_1 / odds_2  # odds ratio
  N <- sum(f[1:4])  # number of species - 88 in this example
  f[1:4] ~ dmulti(pr[], N)  # numbers drawn from a multinomial distribution
  k1[1] <- 0  # parameters for reference classes set to zero
  k2[1] <- 0
  k12[1,1] <- 0  # k12[]'s are the interaction terms
  k12[1,2] <- 0
  k12[2,1] <- 0   
  k1[2] ~ dnorm(0, 1.0E-6)  # effect of 
  k2[2] ~ dnorm(0, 1.0E-6)  # effect of 
  k12[2,2] ~ dnorm(0, 1.0E-6)  # interaction term
 }
write.model(Logmodel, "Model.txt")

# Bundle data
win.data <- list(f=tabla_datos, PRED=c(1,1,2,2), NPRED=c(1,2,1,2))

# Inits function
inits <- function(){list(k1=c(NA,0), k2=c(NA,0), k12=structure(.Data=c(NA,NA,NA,0), .Dim=c(2,2)))}

# Parameters to estimate
params <- c("odds_ratio_12","odds_1","odds_2","k1", "k2", "k12")

# MCMC settings
nc = 1 
ni=10000
nb=1000
nt=1

# Start Gibbs sampler
out <- bugs(data = win.data, inits = inits, parameters = params, model = "model.txt",
n.thin = nt, n.chains = nc, n.burnin = nb, n.iter = ni, debug = FALSE, digits=5, working.directory=getwd())
print(out,digits.summary=2)

if (k==1) {
Tab_odds_fem[j,1] <- out$summary[1,1]
Tab_odds_fem[j,2] <- out$summary[1,5]
Tab_odds_fem[j,3] <- out$summary[1,3]
Tab_odds_fem[j,4] <- out$summary[1,7]
Tab_odds_fem_f[j,1] <-(tabla_datos[4]*tabla_datos[1])/(tabla_datos[2]*tabla_datos[3])
Tab_odds_fem_f[j,2] <- sqrt(sum(1/tabla_datos)) 
Tab_odds_fem_f[j,3] <- exp(log(Tab_odds_fem_f[j,1])-(qnorm(0.975,0,1)*(Tab_odds_fem_f[j,2]))) 
Tab_odds_fem_f[j,4] <- exp(log(Tab_odds_fem_f[j,1])+(qnorm(0.975,0,1)*(Tab_odds_fem_f[j,2])))
           }

if (k==2) {
Tab_odds_mal[j,1] <- out$summary[1,1]
Tab_odds_mal[j,2] <- out$summary[1,5]
Tab_odds_mal[j,3] <- out$summary[1,3]
Tab_odds_mal[j,4] <- out$summary[1,7]
Tab_odds_mal_f[j,1] <- (tabla_datos[4]*tabla_datos[1])/(tabla_datos[2]*tabla_datos[3])
Tab_odds_mal_f[j,2] <- sqrt(sum(1/tabla_datos))
Tab_odds_mal_f[j,3] <- exp(log(Tab_odds_mal_f[j,1])-(qnorm(0.975,0,1)*(Tab_odds_mal_f[j,2])))
Tab_odds_mal_f[j,4] <- exp(log(Tab_odds_mal_f[j,1])+(qnorm(0.975,0,1)*(Tab_odds_mal_f[j,2])))
           }
}
}
Tab_odds_fem
Tab_odds_mal
Tab_odds_fem_f
Tab_odds_mal_f

a <- seq(1,5,2)
b <- seq(1.2,5.2,2)
plot(a,Tab_odds_fem[,1],pch=16,,cex=1.2,xlim=c(0.5,7.5),ylim=c(0,13), ylab="odds ratio", xlab="female=black, male=blue")
abline(h=1,col="red")
points(b,Tab_odds_fem_f[,1],pch=16,,cex=1.2,col="darkgray")
for (i in 1:3){
 lines(c(a[i],a[i]),c(Tab_odds_fem[i,3],Tab_odds_fem[i,4]))}
for (i in 1:3){
 lines(c(b[i],b[i]),c(Tab_odds_fem_f[i,3],Tab_odds_fem_f[i,4]))}
points(a+1,Tab_odds_mal[,1],pch=16,,cex=1.2,col="blue")
points(b+1,Tab_odds_mal_f[,1],pch=16,,cex=1.2,col="cyan")
for (i in 1:3){
 lines(c(a[i]+1,a[i]+1),c(Tab_odds_mal[i,3],Tab_odds_mal[i,4]))}
for (i in 1:3){
 lines(c(b[i]+1,b[i]+1),c(Tab_odds_mal_f[i,3],Tab_odds_mal_f[i,4]))}

## detach the data
detach(count_data)